==> zio-aws-rekognition_2.12-5.17.116.1-sources.jar: zio/aws/rekognition/model/TrainingDataResult.scala <==
package zio.aws.rekognition.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class TrainingDataResult(
    input: Option[zio.aws.rekognition.model.TrainingData] = None,
    output: Option[zio.aws.rekognition.model.TrainingData] = None,
    validation: Option[zio.aws.rekognition.model.ValidationData] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.TrainingDataResult = {
    import TrainingDataResult.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.TrainingDataResult
      .builder()
      .optionallyWith(input.map(value => value.buildAwsValue()))(_.input)
      .optionallyWith(output.map(value => value.buildAwsValue()))(_.output)
      .optionallyWith(validation.map(value => value.buildAwsValue()))(
        _.validation
      )
      .build()
  }
  def asReadOnly: zio.aws.rekognition.model.TrainingDataResult.ReadOnly =
    zio.aws.rekognition.model.TrainingDataResult.wrap(buildAwsValue())
}
object TrainingDataResult {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.TrainingDataResult
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.TrainingDataResult =
      zio.aws.rekognition.model.TrainingDataResult(
        input.map(value => value.asEditable),
        output.map(value => value.asEditable),
        validation.map(value => value.asEditable)
      )
    def input: Option[zio.aws.rekognition.model.TrainingData.ReadOnly]
    def output: Option[zio.aws.rekognition.model.TrainingData.ReadOnly]
    def validation: Option[zio.aws.rekognition.model.ValidationData.ReadOnly]
    def getInput
        : ZIO[Any, AwsError, zio.aws.rekognition.model.TrainingData.ReadOnly] =
      AwsError.unwrapOptionField("input", input)
    def getOutput
        : ZIO[Any, AwsError, zio.aws.rekognition.model.TrainingData.ReadOnly] =
      AwsError.unwrapOptionField("output", output)
    def getValidation: ZIO[
      Any,
      AwsError,
      zio.aws.rekognition.model.ValidationData.ReadOnly
    ] = AwsError.unwrapOptionField("validation", validation)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.TrainingDataResult
  ) extends zio.aws.rekognition.model.TrainingDataResult.ReadOnly {
    override val input
        : Option[zio.aws.rekognition.model.TrainingData.ReadOnly] = scala
      .Option(impl.input())
      .map(value => zio.aws.rekognition.model.TrainingData.wrap(value))
    override val output
        : Option[zio.aws.rekognition.model.TrainingData.ReadOnly] = scala
      .Option(impl.output())
      .map(value => zio.aws.rekognition.model.TrainingData.wrap(value))
    override val validation
        : Option[zio.aws.rekognition.model.ValidationData.ReadOnly] = scala
      .Option(impl.validation())
      .map(value => zio.aws.rekognition.model.ValidationData.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.TrainingDataResult
  ): zio.aws.rekognition.model.TrainingDataResult.ReadOnly = new Wrapper(impl)
}

==> zio-aws-rekognition_2.12-5.20.7.3-sources.jar: zio/aws/rekognition/model/TrainingDataResult.scala <==
package zio.aws.rekognition.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class TrainingDataResult(
    input: Optional[zio.aws.rekognition.model.TrainingData] = Optional.Absent,
    output: Optional[zio.aws.rekognition.model.TrainingData] = Optional.Absent,
    validation: Optional[zio.aws.rekognition.model.ValidationData] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.TrainingDataResult = {
    import TrainingDataResult.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.TrainingDataResult
      .builder()
      .optionallyWith(input.map(value => value.buildAwsValue()))(_.input)
      .optionallyWith(output.map(value => value.buildAwsValue()))(_.output)
      .optionallyWith(validation.map(value => value.buildAwsValue()))(
        _.validation
      )
      .build()
  }
  def asReadOnly: zio.aws.rekognition.model.TrainingDataResult.ReadOnly =
    zio.aws.rekognition.model.TrainingDataResult.wrap(buildAwsValue())
}
object TrainingDataResult {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.TrainingDataResult
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.TrainingDataResult =
      zio.aws.rekognition.model.TrainingDataResult(
        input.map(value => value.asEditable),
        output.map(value => value.asEditable),
        validation.map(value => value.asEditable)
      )
    def input: Optional[zio.aws.rekognition.model.TrainingData.ReadOnly]
    def output: Optional[zio.aws.rekognition.model.TrainingData.ReadOnly]
    def validation: Optional[zio.aws.rekognition.model.ValidationData.ReadOnly]
    def getInput
        : ZIO[Any, AwsError, zio.aws.rekognition.model.TrainingData.ReadOnly] =
      AwsError.unwrapOptionField("input", input)
    def getOutput
        : ZIO[Any, AwsError, zio.aws.rekognition.model.TrainingData.ReadOnly] =
      AwsError.unwrapOptionField("output", output)
    def getValidation: ZIO[
      Any,
      AwsError,
      zio.aws.rekognition.model.ValidationData.ReadOnly
    ] = AwsError.unwrapOptionField("validation", validation)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.TrainingDataResult
  ) extends zio.aws.rekognition.model.TrainingDataResult.ReadOnly {
    override val input
        : Optional[zio.aws.rekognition.model.TrainingData.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.input())
        .map(value => zio.aws.rekognition.model.TrainingData.wrap(value))
    override val output
        : Optional[zio.aws.rekognition.model.TrainingData.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.output())
        .map(value => zio.aws.rekognition.model.TrainingData.wrap(value))
    override val validation
        : Optional[zio.aws.rekognition.model.ValidationData.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.validation())
        .map(value => zio.aws.rekognition.model.ValidationData.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.TrainingDataResult
  ): zio.aws.rekognition.model.TrainingDataResult.ReadOnly = new Wrapper(impl)
}
